/* 
 * i-scream central monitoring system
 * http://www.i-scream.org
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.server.filter;

//---IMPORTS---
import java.net.*;
import java.io.*;

/**
 * A skeleton class for Service Checks to extend.
 *
 * @author  $Author: tdb $
 * @version $Id: ServiceCheckSkeleton.java,v 1.8 2004/08/01 10:40:59 tdb Exp $
 */
public abstract class ServiceCheckSkeleton implements PluginServiceCheck {

//---FINAL ATTRIBUTES---
    
//---STATIC METHODS---

//---CONSTRUCTORS---

//---PUBLIC METHODS---
    
    /**
     * Runs a service check on a given hostname.
     *
     * @param hostname The hostname to check
     */
    public abstract String runServiceCheck(String hostname);
    
    /**
     * Checks if a service is returning a valid response, and
     * constructs suitable XML for inclusion in a packet.
     *
     * @param hostname The hostname to query
     * @param port The port to query
     * @param expectedSubString The String to look for in the response
     * @param XMLTag The name of the tag to be put in the XML
     * @return The String of XML with the response information
     */
    protected String checkService(String hostname, int port, String expectedSubString, String XMLTag) {
        String message, status;
        try {
            // connect and get response
            String response = connectToService(hostname, port);
            // check if the expected text is in the response
            if(response.indexOf(expectedSubString) != -1) {
                status = "0";
                message = "Good Header received: "+response;
            }
            else {
                status = "1";
                message = "Bad Header received: "+response;
            }
        } catch (IOException e) {
            // connect failed
            status = "1";
            message = "Service check failed to establish connection to host: " + e.getMessage();
        }
        return "<"+XMLTag+" status=\"" + status + "\" message=\"" + message + "\"></"+XMLTag+">";
    }
    
    /**
     * Connects to a service and returns the first line of text.
     *
     * @param hostname The hostname of the service to check
     * @param port The port of the service to check
     * @return The first line of text given
     * @throws IOException if the connection fails for some reason
     */
    protected String connectToService(String hostname, int port) throws IOException {
        // connect
        Socket socket = new Socket(hostname, port);
        BufferedReader socketIn = new BufferedReader(new InputStreamReader(socket.getInputStream()));
        // read first line
        String response = socketIn.readLine();
        // close
        socketIn.close();
        socket.close();
        // return first line
        return response;
    }
    
    /**
     * Used to query the Service Check to see what it does.
     *
     * @return the String representation of what the Service Check does
     */
    public abstract String getDescription();

//---PRIVATE METHODS---

//---ACCESSOR/MUTATOR METHODS---

//---ATTRIBUTES---

//---STATIC ATTRIBUTES---

}
